# KnifeSwap by David Bowland
# ./addons/eventscripts/knifeswap/knifeswap.py

# >>> To configure this addon please see knifeswap.cfg (created when the addon is first loaded) <<<

"""
Provides a client command to swap between the knife and last active weapon.
Requires only ES 2.0.0.250c+
"""


import cfglib
import cmdlib
import es
import langlib
import os.path
import playerlib

import psyco
psyco.full()


info = es.AddonInfo()
info.name     = 'KnifeSwap'
info.version  = '3'
info.basename = 'knifeswap'
info.url      = 'http://addons.eventscripts.com/addons/view/' + info.basename
info.author   = 'SuperDave'

###

config = cfglib.AddonCFG(os.path.join(es.getAddonPath(info.basename), info.basename + '.cfg'))

config.text(info.name + ' release %s options' % info.version)
config.text('./addons/eventscripts/%(basename)s/%(basename)s.cfg' % {'basename': info.basename})
config.text(info.url)
config.text('')
config.text('Load this addon with: es_load ' + info.basename)
config.text('\n')
config.text('To configure language settings for %s please see %s_languages.ini' % (info.name, info.basename))
config.text('\n')

config.text('***** Options *****')
cvar_announce_chat = config.cvar('knifeswap_announce_chat', 2, '0 = no change, 1 = announce knife swap command on the console at the beginning of the round, 2 = announce knife swap command in chat area at the beginning of the round')
cvar_announce_hud  = config.cvar('knifeswap_announce_hud',  1, '0 = no change, 1 = announce knife swap command in a HUD hint at the beginning of the round')

config.write()

###

ini = cfglib.AddonINI(os.path.join(es.getAddonPath(info.basename), info.basename + '_languages.ini'))

ini.setInitialComments(['# ./addons/eventscripts/%(basename)s/%(basename)s_languages.ini' % {'basename': info.basename},
 '# >>> For general addon configuration see ' + info.basename + '.cfg <<<', '', '# DO NOT translate words with $ or # in front!',
 '# For a list of language abbreviations please see ./addons/eventscripts/_libs/python/deflangs.ini'])

ini.addGroup('command announce')
ini.addValueToGroup('command announce', 'en', '#defaultBind a key to  #lightgreenknifeswap#default  to swap between your knife and previous weapon.')
ini.addValueToGroup('command announce', 'de', '#defaultBinde eine Taste auf  #lightgreenknifeswap#default  um zwischen Messer und vorheriger Waffe wechseln zu koennen.')
ini.addValueToGroup('command announce', 'fr', "#defaultAssignez une touche pour  #lightgreenknifeswap#default  afin d'intervertir entre votre couteau et votre arme.")

ini.write()
lang_text = langlib.Strings(ini)

###

class KnifeSwapManager(object):
   def __init__(self):
      cmdlib.registerClientCommand('knifeswap', self.swapCmd, 'Command to swap between the knife and last active weapon')

   def swapCmd(self, userid, args):
      """ Swaps between the knife and previous weapon """
      # If the player has his or her knife active, switch to the previous weapon
      if es.createplayerlist(userid)[userid]['weapon'] == 'weapon_knife':
         es.cexec(userid, 'lastinv')
      # If the player doesn't have his or her knife active, switch to the knife 
      else:
         es.sexec(userid, 'use weapon_knife')

   def roundStart(self):
      """ Announces the swap command at the beginning of the round """
      chat = int(cvar_announce_chat)
      hud  = int(cvar_announce_hud)
      if chat and hud:
         for player in playerlib.getPlayerList('#alive'):
            lang = player.getLanguage()
            if chat:
               if chat == 1:
                  es.cexec(player.userid, 'echo ' + self.removeTags(lang_text('command announce', lang=lang)))
               else:
                  es.tell(player.userid, '#multi', lang_text('command announce', lang=lang))
            if hud:
               self.hudHint(player.userid, self.removeTags(lang_text('command announce', lang=lang)))

   @staticmethod
   def hudHint(userid, message):
      """ Sends a player a HUD hint """
      es.usermsg('create', 'knifeswap_hud', 'HintText')
      es.usermsg('write', 'byte', 'knifeswap_hud', -1)
      es.usermsg('write', 'string', 'knifeswap_hud', message)
      es.usermsg('send', 'knifeswap_hud', userid)
      es.usermsg('delete', 'knifeswap_hud')

   @staticmethod
   def removeTags(text):
      """ Removes #lightgreen, #green and #default tags from the supplied string """
      return text.replace('#lightgreen', '').replace('#green', '').replace('#default', '')

   @staticmethod
   def unregisterCommand():
      cmdlib.unregisterClientCommand('knifeswap')

knifeswap = KnifeSwapManager()

###

def load():
   config.execute()


def round_start(event_var):
   knifeswap.roundStart()


def unload():
   knifeswap.unregisterCommand()

   for cvar in config.getCvars():
      es.ServerVar(cvar).set(0)